summaryrefslogtreecommitdiffstats
path: root/test/links_env.c
diff options
context:
space:
mode:
authorAllen Byrne <byrn@hdfgroup.org>2019-07-31 20:18:58 (GMT)
committerAllen Byrne <byrn@hdfgroup.org>2019-07-31 20:18:58 (GMT)
commitc8d32112f87e0c79999e33cc40cb411da1642b5c (patch)
treeac3d1dfffa72156bac18aefbf3b76a255ea06478 /test/links_env.c
parentc1a6ba6b648fe4c42dca2ada0f0e8e2c904e3f9e (diff)
downloadhdf5-c8d32112f87e0c79999e33cc40cb411da1642b5c.zip
hdf5-c8d32112f87e0c79999e33cc40cb411da1642b5c.tar.gz
hdf5-c8d32112f87e0c79999e33cc40cb411da1642b5c.tar.bz2
HDFFV-10845 More changes from 1.10 branch
Diffstat (limited to 'test/links_env.c')
-rw-r--r--test/links_env.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/test/links_env.c b/test/links_env.c
index ef6c5e5..470ef9a 100644
--- a/test/links_env.c
+++ b/test/links_env.c
@@ -136,8 +136,8 @@ external_link_env(hid_t fapl, hbool_t new_format)
*
* Purpose: Test external link with environment variable HDF5_EXT_PREFIX
*
* Return: Success: exit(0)
* Failure: exit(non-zero)
*
* Programmer: Vailin Choi; Nov 2010
*
@@ -171,11 +171,11 @@ main(void)
/* Results */
if(nerrors) {
- printf("***** %d External Link (HDF5_EXT_PREFIX) test%s FAILED! *****\n",
+ HDprintf("***** %d External Link (HDF5_EXT_PREFIX) test%s FAILED! *****\n",
nerrors, 1 == nerrors ? "" : "s");
- exit(1);
+ HDexit(EXIT_FAILURE);
}
- printf("All external Link (HDF5_EXT_PREFIX) tests passed.\n");
+ HDprintf("All external Link (HDF5_EXT_PREFIX) tests passed.\n");
/* clean up tmp directory created by external link tests */
HDrmdir(TMPDIR);
@@ -183,6 +183,6 @@ main(void)
return 0;
error:
- puts("*** TESTS FAILED ***");
+ HDputs("*** TESTS FAILED ***");
return 1;
}
@@ -136,8 +136,8 @@ external_link_env(hid_t fapl, hbool_t new_format)
* Purpose: Test external link with environment variable HDF5_EXT_PREFIX
*
- * Return: Success: exit(0)
- * Failure: exit(non-zero)
+ * Return: Success: exit(EXIT_SUCCESS)
+ * Failure: exit(EXIT_FAILURE)
*
* Programmer: Vailin Choi; Nov 2010